@@ -4,6 +4,7 @@ from resilipy.scripts.labeler import Labeler
 
 import webbrowser
 import sys
+import os
 from PyQt6 import uic
 from PyQt6.QtWidgets import QMainWindow, QApplication
 
@@ -11,7 +12,9 @@ from PyQt6.QtWidgets import QMainWindow, QApplication
 class ResiliPy(QMainWindow):
     def __init__(self):
         super().__init__()
-        uic.loadUi("./resilipy/ui/resilipy.ui", self)
+        dirname = os.path.dirname(__file__)
+        ui = os.path.join(dirname, "resilipy/ui/resilipy.ui")
+        uic.loadUi(ui, self)
         self.builder = None
         self.preprocessor = None
         self.labeler = None
